echo "Inside Chroot Env"
echo
source /environment.sh
pwd
echo
echo ${PASSWORD}
echo ${USER}
echo ${DISK}


echo "Installing Important Packages"

mkinitcpio -P

#install from lists
gpg --refresh-keys
pacman-key --init && pacman-key --populate
pacman-key --refresh-keys
pacman -Syy

pacman -S --noconfirm man-pages man-db dnsutils ethtool iputils net-tools iproute2 openssh wget \
usbutils usb_modeswitch tcpdump smartmontools  gnu-netcat mc dosfstools exfat-utils \
partclone parted partimage gptfdisk iw dialog base-devel vim \
grub os-prober efivar efibootmgr efitools intel-ucode amd-ucode dmidecode htop nano python python-setuptools slurm-llnl nfs-utils saturn-discover lmod python-pipenv saturn-power wol rdma-core pod2man gcc13 saturn-jupyter

cd /usr/bin/
ln -s vim vi

echo "Setup Timezone and Locale"

ln -sf /usr/share/zoneinfo/Europe/Prague /etc/localtime

hwclock --systohc

echo "en_GB.UTF-8 UTF-8" >> /etc/locale.gen
locale-gen
echo "LANG=en_GB.UTF-8" >> /etc/locale.conf

echo "Network Setup"

dmidecode --string system-uuid | cut -c1-8 > /etc/hostname

echo "127.0.0.1	localhost" > /etc/hosts
echo "::1		localhost" >> /etc/hosts

# for IPv6:
# DHCP=yes

echo "[Match]"         > /etc/systemd/network/20-wired.network
echo "Name=${NET}"     >> /etc/systemd/network/20-wired.network
echo ""                >> /etc/systemd/network/20-wired.network
echo "[Network]"       >> /etc/systemd/network/20-wired.network
echo "DHCP=ipv4"       >> /etc/systemd/network/20-wired.network
echo ""                >> /etc/systemd/network/20-wired.network
echo "[DHCPv6]"        >> /etc/systemd/network/20-wired.network
echo "UseDomains=true" >> /etc/systemd/network/20-wired.network

echo "Adding Users"

groupadd wheel
groupadd sudo

useradd -m -G users,sudo -s /bin/bash ${USER}
yes ${PASSWORD} | passwd
yes ${PASSWORD} | passwd ${USER}

usermod -a -G wheel slurm

echo "%sudo ALL=(ALL:ALL) ALL" >> /etc/sudoers
echo "%wheel ALL=(ALL:ALL) NOPASSWD: ALL" >> /etc/sudoers

useradd -m -G users,wheel -s /bin/bash maintenance
ssh-keygen -t ed25519 -C "maintenance" -f /root/.ssh/maintenance -N ''

mkdir /home/maintenance/.ssh
cat /root/.ssh/maintenance.pub >> /home/maintenance/.ssh/authorized_keys

echo "Installing GRUB"

mkdir /boot/grub
grub-mkconfig -o /boot/grub/grub.cfg
grub-install ${DISK}


echo "Enabling services"
systemctl enable systemd-networkd
systemctl enable systemd-resolved
systemctl enable systemd-timesyncd
systemctl enable sshd

timedatectl set-timezone $timezone
timedatectl set-ntp true

echo "Generating issue"

echo "             ___       ,-\`."             >  /etc/issue
echo "         .-~~   ~~-.,-~ _~ "              >> /etc/issue
echo "       #\`           \`._-   "            >> /etc/issue
echo "      .\`           _-~.    "             >> /etc/issue
echo "      |          _-   |    "              >> /etc/issue
echo "      \`       _-~     '    "             >> /etc/issue
echo "  . _-~\`. _-~       .'     "             >> /etc/issue
echo " ,-' _,-~\`-__   __-'       "             >> /etc/issue
echo ",.-~\`   .    ~~~           "             >> /etc/issue
echo "                           "              >> /etc/issue
echo "        SatrunArch         "              >> /etc/issue
echo                                            >> /etc/issue
echo "IP Addresses:"                            >> /etc/issue
echo "    \\4"                                  >> /etc/issue
echo "    \\6"                                  >> /etc/issue
echo                                            >> /etc/issue
echo "Default login:"                           >> /etc/issue
echo "    user: ${USER}"                        >> /etc/issue
echo "    pass: ${PASSWORD}"                    >> /etc/issue
echo                                            >> /etc/issue

# setup cluster

sudo mkdir /clusterfs
sudo chown nobody.nogroup /clusterfs
sudo chmod -R 777 /clusterfs

mkdir /clusterfs/config
sudo chown root /clusterfs/config
sudo chmod -R 700 /clusterfs/config

cp /root/.ssh/maintenance.pub /clusterfs/config/maintenance.pub

# todo security check here
echo "/clusterfs  (rw,sync,no_root_squash,no_subtree_check)" >> /etc/exports
echo "/home       (rw,sync,no_root_squash,no_subtree_check)" >> /etc/exports

# copy keys and config
mkdir /clusterfs/config
cp /etc/munge/munge.key /clusterfs/config
cp /etc/slurm-llnl/slurm.conf.template /clusterfs/config

systemctl enable munge
systemctl enable slurmd
systemctl enable slurmctld
systemctl enable nfs-server
systemctl enable saturnDiscover

touch /etc/slurm-llnl/MASTER

mkdir /var/lib/slurm/
chown slurm:slurm /var/lib/slurm/

pipenv install easybuild setuptools
mkdir /clusterfs/modules
chown -R root:sudo /clusterfs/modules/
chmod 775 -R /clusterfs/modules
source /etc/profile.d/modules.sh
pipenv run eb --install-latest-eb-release --prefix /clusterfs/modules --robot --allow-use-as-root-and-accept-consequences

pipenv uninstall easybuild
module use /clusterfs/modules/modules/all/
ml EasyBuild

#export EASYBUILD_IGNORE_OSDEPS=1
#export EASYBUILD_SYSROOT=${EPREFIX}
#export EASYBUILD_RPATH=1
#export EASYBUILD_FILTER_ENV_VARS=LD_LIBRARY_PATH
#export EASYBUILD_FILTER_DEPS=Autoconf,Automake,Autotools,binutils,bzip2,cURL,DBus,flex,gettext,gperf,help2man,intltool,libreadline,libtool,Lua,M4,makeinfo,ncurses,util-linux,XZ,zlib
#export EASYBUILD_MODULE_EXTENSIONS=1

#export CC='gcc-13'
#export CXX='g++-13'
#alias gcc='gcc-13'
#alias g++='g++-13'
#export cc='gcc-13'
#export cxx='g++-13'

# install GCC13 as module
pipenv run eb GCCcore-13.3.0.eb --allow-use-as-root-and-accept-consequences --robot --prefix /clusterfs/modules --minimal-build-env="CC:gcc-13,CXX:g++-13"

# install GCC11 as module
#pipenv run eb GCCcore-11.3.0.eb --allow-use-as-root-and-accept-consequences --robot --prefix /clusterfs/modules --minimal-build-env="CC:gcc-13,CXX:g++-13"

# install foss toolchain as module
#ml GCCcore/13.3.0
#pipenv run eb --software-name=foss --allow-use-as-root-and-accept-consequences --robot --prefix /clusterfs/modules --ignore-osdeps

# install git as module
pipenv run eb --software-name=git --robot --prefix /clusterfs/modules --skip-test-step --toolchain-name=GCCcore --allow-use-as-root-and-accept-consequences

pipenv uninstall setuptools

echo "source /etc/profile.d/modules.sh" >> /etc/bash.bashrc
echo "module use /clusterfs/modules/modules/*" >> /etc/bash.bashrc

echo "Exiting Chroot Environment"

exit

